@@ -102,15 +102,32 @@ OctaviaGroup = [
                     'default RBAC tests. "owner_or_admin" runs the legacy '
                     'owner or admin tests. "none" disables the RBAC tests.'),
     cfg.DictOpt('enabled_provider_drivers',
-                help=('List of enabled provider drivers and description '
-                      'dictionaries. Must match the driver name in the '
+                help=('A comma separated list of dictionaries of the '
+                      'enabled provider driver names and descriptions. '
+                      'Must match the driver name in the '
                       'octavia.api.drivers entrypoint. Example: '
-                      '{\'amphora\': \'The Octavia Amphora driver.\', '
-                      '\'octavia\': \'Deprecated alias of the Octavia '
-                      'Amphora driver.\'}'),
+                      'amphora:The Octavia Amphora driver.,'
+                      'octavia:Deprecated alias of the Octavia '
+                      'Amphora driver.'),
                 default={'amphora': 'The Octavia Amphora driver.',
                          'octavia': 'Deprecated alias of the Octavia Amphora '
                          'driver.'}),
+    cfg.StrOpt('loadbalancer_topology',
+               default=const.SINGLE,
+               choices=const.SUPPORTED_LB_TOPOLOGIES,
+               help='Load balancer topology configuration.'),
+    cfg.DictOpt('expected_flavor_capability',
+                help=('Defines a provider flavor capability that is expected '
+                      'to be present in the selected provider under test. '
+                      'It is specified in a "name": "description" dict. '
+                      'Example: {"loadbalancer_topology": "The load balancer '
+                      'topology. One of: SINGLE - One amphora per load '
+                      'balancer. ACTIVE_STANDBY - Two amphora per load '
+                      'balancer."}'),
+                default={'loadbalancer_topology': 'The load balancer '
+                         'topology. One of: SINGLE - One amphora per load '
+                         'balancer. ACTIVE_STANDBY - Two amphora per load '
+                         'balancer.'}),
     # Networking
     cfg.BoolOpt('test_with_ipv6',
                 default=True,
@@ -192,4 +209,12 @@ LBFeatureEnabledGroup = [
                default="TCP",
                help="The type of L4 Protocol which is supported with the "
                     "provider driver."),
+    cfg.BoolOpt('spare_pool_enabled',
+                default=False,
+                help="Wether spare pool is available with amphora provider "
+                "driver or not."),
+    cfg.BoolOpt('session_persistence_enabled',
+                default=True,
+                help="Whether session persistence is supported with the "
+                     "provider driver."),
 ]
