@@ -121,13 +121,15 @@ class LoadBalancerBaseTest(test.BaseTestCase):
             cls.os_roles_lb_member.healthmonitor_client)
         cls.mem_l7policy_client = cls.os_roles_lb_member.l7policy_client
         cls.mem_l7rule_client = cls.os_roles_lb_member.l7rule_client
-        cls.mem_amphora_client = cls.os_roles_lb_member.amphora_client
+        cls.lb_admin_amphora_client = cls.os_roles_lb_admin.amphora_client
         cls.lb_admin_flavor_profile_client = (
             cls.os_roles_lb_admin.flavor_profile_client)
         cls.lb_admin_flavor_client = cls.os_roles_lb_admin.flavor_client
         cls.mem_flavor_client = cls.os_roles_lb_member.flavor_client
         cls.mem_provider_client = cls.os_roles_lb_member.provider_client
         cls.os_admin_servers_client = cls.os_admin.servers_client
+        cls.lb_admin_capabilities_client = (
+            cls.os_roles_lb_admin.flavor_capabilities_client)
 
     @classmethod
     def resource_setup(cls):
@@ -157,6 +159,7 @@ class LoadBalancerBaseTest(test.BaseTestCase):
                                                  uuidutils.generate_uuid()}
                 cls.lb_member_1_ipv6_subnet = {'id': uuidutils.generate_uuid()}
                 cls.lb_member_2_ipv6_subnet = {'id': uuidutils.generate_uuid()}
+                cls.lb_member_vip_ipv6_subnet_stateful = True
             return
         elif CONF.load_balancer.test_network_override:
             if conf_lb.test_subnet_override:
@@ -182,6 +185,10 @@ class LoadBalancerBaseTest(test.BaseTestCase):
                 cls.lb_member_vip_ipv6_subnet = override_ipv6_subnet
                 cls.lb_member_1_ipv6_subnet = override_ipv6_subnet
                 cls.lb_member_2_ipv6_subnet = override_ipv6_subnet
+                cls.lb_member_vip_ipv6_subnet_stateful = False
+                if (override_ipv6_subnet[0]['ipv6_address_mode'] ==
+                        'dhcpv6-stateful'):
+                    cls.lb_member_vip_ipv6_subnet_stateful = True
             else:
                 cls.lb_member_vip_ipv6_subnet = None
                 cls.lb_member_1_ipv6_subnet = None
@@ -303,7 +310,11 @@ class LoadBalancerBaseTest(test.BaseTestCase):
             priv_ipv6_subnet = cls.os_admin.subnets_client.list_subnets(
                 name='ipv6-private-subnet')['subnets']
 
+            cls.lb_member_vip_ipv6_subnet_stateful = False
             if len(priv_ipv6_subnet) == 1:
+                if (priv_ipv6_subnet[0]['ipv6_address_mode'] ==
+                        'dhcpv6-stateful'):
+                    cls.lb_member_vip_ipv6_subnet_stateful = True
                 cls.lb_member_vip_ipv6_subnet = priv_ipv6_subnet[0]
                 cls.lb_member_vip_ipv6_net = {
                     'id': priv_ipv6_subnet[0]['network_id']}
@@ -322,6 +333,7 @@ class LoadBalancerBaseTest(test.BaseTestCase):
                     cls._logging_delete_subnet,
                     cls.lb_mem_subnet_client.show_subnet,
                     cls.lb_member_vip_ipv6_subnet['id'])
+
             LOG.info('lb_member_vip_ipv6_subnet: {}'.format(
                 cls.lb_member_vip_ipv6_subnet))
 
@@ -457,6 +469,10 @@ class LoadBalancerBaseTest(test.BaseTestCase):
                     subnet = cls.os_admin.subnets_client.show_subnet(subnet_id)
                     network = ipaddress.IPv6Network(subnet['subnet']['cidr'])
                     lb_vip_address = str(network[ip_index])
+                    # If the subnet is IPv6 slaac or dhcpv6-stateless
+                    # neutron does not allow a fixed IP
+                    if not cls.lb_member_vip_ipv6_subnet_stateful:
+                        use_fixed_ip = False
             lb_kwargs[const.VIP_SUBNET_ID] = subnet_id
             if use_fixed_ip:
                 lb_kwargs[const.VIP_ADDRESS] = lb_vip_address
@@ -790,6 +806,17 @@ class LoadBalancerBaseTestWithCompute(LoadBalancerBaseTest):
             if proc.returncode != 0:
                 raise exceptions.CommandFailed(proc.returncode, cmd,
                                                stdout, stderr)
+
+        # Enabling memory overcommit allows to run golang static binaries
+        # compiled with a recent golang toolchain (>=1.11). Those binaries
+        # allocate a large amount of virtual memory at init time, and this
+        # allocation fails in tempest's nano flavor (64MB of RAM)
+        # (golang issue reported in https://github.com/golang/go/issues/28114,
+        # follow-up: https://github.com/golang/go/issues/28081)
+        # TODO(gthiemonge): Remove this call when golang issue is resolved.
+        linux_client.exec_command('sudo sh -c "echo 1 > '
+                                  '/proc/sys/vm/overcommit_memory"')
+
         linux_client.exec_command('sudo screen -d -m {0} -port 80 '
                                   '-id {1}'.format(dest_file, start_id))
         linux_client.exec_command('sudo screen -d -m {0} -port 81 '
